pub struct ConfigurationOverridesDTO {
pub Resource: Option<Value>,
pub OverrideIdentifier: Option<String>,
}Expand description
A serializable struct for specifying overrides when retrieving or inspecting configuration values.
This allows for fetching settings that are specific to a particular resource
(like a file URI) or a language (like settings inside a [rust] block).
Fields
Resource: Option<Value>The resource URI to which the configuration should be scoped.
This is used to resolve resource-specific and folder-specific settings.
The value is a serialized UriComponents DTO.
OverrideIdentifier: Option<String>The language identifier for language-specific overrides.
This is used to resolve [language] blocks in settings.json.